@@ -1,6 +1,6 @@
 package Magpie::ConfigReader::XML;
 {
-  $Magpie::ConfigReader::XML::VERSION = '1.131380';
+  $Magpie::ConfigReader::XML::VERSION = '1.140260';
 }
 #ABSTRACT: Magpie Configuration via XML
 
@@ -8,6 +8,7 @@ use Moose;
 use XML::LibXML;
 use Magpie::Util;
 use Magpie::Plugin::URITemplate;
+use Class::Load;
 
 #use Data::Printer;
 
@@ -246,7 +247,7 @@ sub process_accept_matrix {
 }
 
 sub process_assets {
-    Class::MOP::load_class('Bread::Board');
+    Class::Load::load_class('Bread::Board');
     my $self = shift;
     my $node = shift;
     foreach my $container ($node->findnodes('./container')) {
@@ -409,7 +410,7 @@ Magpie::ConfigReader::XML - Magpie Configuration via XML
 
 =head1 VERSION
 
-version 1.131380
+version 1.140260
 
 =head1 AUTHORS
 
